@@ -3,7 +3,7 @@
  */
 /* Copyright 1999,2000,2001 BrightStation PLC
  * Copyright 2002 Ananova Ltd
- * Copyright 2002,2003,2004,2005,2006,2007,2008,2009,2011,2012,2013,2014,2015,2016 Olly Betts
+ * Copyright 2002,2003,2004,2005,2006,2007,2008,2009,2011,2012,2013,2014,2015,2016,2017 Olly Betts
  * Copyright 2006,2008 Lemur Consulting Ltd
  *
  * This program is free software; you can redistribute it and/or
@@ -438,7 +438,7 @@ class XAPIAN_VISIBILITY_DEFAULT Database {
 	/** Get the user-specified metadata associated with a given key.
 	 *
 	 *  User-specified metadata allows you to store arbitrary information
-	 *  in the form of (key,tag) pairs.  See @a
+	 *  in the form of (key, value) pairs.  See @a
 	 *  WritableDatabase::set_metadata() for more information.
 	 *
 	 *  When invoked on a Xapian::Database object representing multiple
@@ -502,6 +502,21 @@ class XAPIAN_VISIBILITY_DEFAULT Database {
 	 */
 	std::string get_uuid() const;
 
+	/** Test if this database is currently locked for writing.
+	 *
+	 *  If the underlying object is actually a WritableDatabase, always
+	 *  returns true.
+	 *
+	 *  Otherwise tests if there's a writer holding the lock (or if
+	 *  we can't test for a lock without taking it on the current platform,
+	 *  throw Xapian::UnimplementedError).  If there's an error while
+	 *  trying to test the lock, throws Xapian::DatabaseLockError.
+	 *
+	 *  For multi-databases, this tests each sub-database and returns
+	 *  true if any of them are locked.
+	 */
+	bool locked() const;
+
 	/** Get the revision of the database.
 	 *
 	 *  The revision is an unsigned integer which increases with each
@@ -1170,11 +1185,11 @@ class XAPIAN_VISIBILITY_DEFAULT WritableDatabase : public Database {
 	 *  existing item of metadata, just set its value to the empty string.
 	 *
 	 *  User-specified metadata allows you to store arbitrary information
-	 *  in the form of (key,tag) pairs.
+	 *  in the form of (key, value) pairs.
 	 *
 	 *  There's no hard limit on the number of metadata items, or the size
 	 *  of the metadata values.  Metadata keys have a limited length, which
-	 *  depends on the backend.  We recommend limiting them to 200 bytes.
+	 *  depend on the backend.  We recommend limiting them to 200 bytes.
 	 *  Empty keys are not valid, and specifying one will cause an
 	 *  exception.
 	 *
@@ -1189,9 +1204,9 @@ class XAPIAN_VISIBILITY_DEFAULT WritableDatabase : public Database {
 	 *  associated with terms, documents, or postings by encoding the
 	 *  termname and/or document id into the metadata key.
 	 *
-	 *  @param key   The key of the metadata item to set.
+	 *  @param key       The key of the metadata item to set.
 	 *
-	 *  @param value The value of the metadata item to set.
+	 *  @param metadata  The value of the metadata item to set.
 	 *
 	 *  @exception Xapian::DatabaseError will be thrown if a problem occurs
 	 *             while writing to the database.
@@ -1206,7 +1221,7 @@ class XAPIAN_VISIBILITY_DEFAULT WritableDatabase : public Database {
 	 *             database backend in use doesn't support user-specified
 	 *             metadata.
 	 */
-	void set_metadata(const std::string & key, const std::string & value);
+	void set_metadata(const std::string & key, const std::string & metadata);
 
 	/// Return a string describing this object.
 	std::string get_description() const;
